==> haskell-unliftio-core-0.1.2.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unliftio-core.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unliftio-core
version: 0.1.2.0
id: unliftio-core-0.1.2.0-900TPot3SR34dceIcVaslS
key: unliftio-core-0.1.2.0-900TPot3SR34dceIcVaslS
license: MIT
copyright: 2017 FP Complete
maintainer: michael@snoyman.com
author: Michael Snoyman, Francesco Mazzoli
homepage: https://github.com/fpco/unliftio/tree/master/unliftio-core#readme
synopsis: The MonadUnliftIO typeclass for unlifting monads to IO
description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio-core>
category: Control
abi: b3bd63f18add30d59629e9599623cc96
exposed: True
exposed-modules:
    Control.Monad.IO.Unlift
hidden-modules: Paths_unliftio_core
import-dirs: /usr/lib/ghc-8.4.3/site-local/unliftio-core-0.1.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/unliftio-core-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/unliftio-core-0.1.2.0
hs-libraries: HSunliftio-core-0.1.2.0-900TPot3SR34dceIcVaslS
depends:
    base-4.11.1.0 transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-unliftio-core/html/unliftio-core.haddock
haddock-html: /usr/share/doc/haskell-unliftio-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unliftio-core-0.1.2.0-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unliftio-core.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unliftio-core
version: 0.1.2.0
id: unliftio-core-0.1.2.0-6l4GP0ylCTM6crlVTDgRiK
key: unliftio-core-0.1.2.0-6l4GP0ylCTM6crlVTDgRiK
license: MIT
copyright: 2017 FP Complete
maintainer: michael@snoyman.com
author: Michael Snoyman, Francesco Mazzoli
homepage: https://github.com/fpco/unliftio/tree/master/unliftio-core#readme
synopsis: The MonadUnliftIO typeclass for unlifting monads to IO
description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio-core>
category: Control
abi: 5fbc59fa7e070bce1a770eb06c1560dd
exposed: True
exposed-modules:
    Control.Monad.IO.Unlift
hidden-modules: Paths_unliftio_core
import-dirs: /usr/lib/ghc-8.6.1/site-local/unliftio-core-0.1.2.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/unliftio-core-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/unliftio-core-0.1.2.0
hs-libraries: HSunliftio-core-0.1.2.0-6l4GP0ylCTM6crlVTDgRiK
depends:
    base-4.12.0.0 transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-unliftio-core/html/unliftio-core.haddock
haddock-html: /usr/share/doc/haskell-unliftio-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
